==> jc-1.4.0.tar.gz: java/util/Collections__24UnmodifiableSet.h <==
// class java.util.Collections$UnmodifiableSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2126b28aee607999 java_util_Collections__24UnmodifiableCollection
// @dep_class aec2ea3fc69f0e47 java_util_Collections__24UnmodifiableSet

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableCollection

#include "java/util/Collections__24UnmodifiableCollection.h"

#ifndef _JC_java_util_Collections__24UnmodifiableSet_H_
#define _JC_java_util_Collections__24UnmodifiableSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableSet$sub_refs	_jc_java_util_Collections__24UnmodifiableSet$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSet$refs	_jc_java_util_Collections__24UnmodifiableSet$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSet$nonrefs	_jc_java_util_Collections__24UnmodifiableSet$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSet$object	_jc_java_util_Collections__24UnmodifiableSet$object;

typedef struct _jc_java_util_Collections__24UnmodifiableSet$fields_struct	_jc_java_util_Collections__24UnmodifiableSet$fields_struct;
typedef const struct _jc_java_util_Collections__24UnmodifiableSet$vmethods	_jc_java_util_Collections__24UnmodifiableSet$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableSet$vtable	_jc_java_util_Collections__24UnmodifiableSet$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableSet$vtype	_jc_java_util_Collections__24UnmodifiableSet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24UnmodifiableSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24UnmodifiableSet$fields_struct _jc_java_util_Collections__24UnmodifiableSet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableSet$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSet$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_java_util_Collections__24UnmodifiableSet$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSet$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_util_Collections__24UnmodifiableSet$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSet$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableSet$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSet$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableSet$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSet$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSet$object *);
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableCollection$vmethods	java_util_Collections__24UnmodifiableCollection;
	_jc_java_util_Collections__24UnmodifiableSet$vmethods	java_util_Collections__24UnmodifiableSet;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableSet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSet$refs {
    _jc_java_util_Collections__24UnmodifiableSet$sub_refs	java_util_Collections__24UnmodifiableSet;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_refs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_nonrefs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs	java_util_Collections__24UnmodifiableSet;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableSet$object {
	_jc_java_util_Collections__24UnmodifiableSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableSet$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableSet$vtype _jc_java_util_Collections__24UnmodifiableSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableSet$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableSet_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24UnmodifiableSet.h <==
// class java.util.Collections$UnmodifiableSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2126b28aee607999 java_util_Collections__24UnmodifiableCollection
// @dep_class aec2ea3fc69f0e47 java_util_Collections__24UnmodifiableSet

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableCollection

#include "java/util/Collections__24UnmodifiableCollection.h"

#ifndef _JC_java_util_Collections__24UnmodifiableSet_H_
#define _JC_java_util_Collections__24UnmodifiableSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableSet$sub_refs	_jc_java_util_Collections__24UnmodifiableSet$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSet$refs	_jc_java_util_Collections__24UnmodifiableSet$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSet$nonrefs	_jc_java_util_Collections__24UnmodifiableSet$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSet$object	_jc_java_util_Collections__24UnmodifiableSet$object;

typedef struct _jc_java_util_Collections__24UnmodifiableSet$fields_struct	_jc_java_util_Collections__24UnmodifiableSet$fields_struct;
typedef const struct _jc_java_util_Collections__24UnmodifiableSet$vmethods	_jc_java_util_Collections__24UnmodifiableSet$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableSet$vtable	_jc_java_util_Collections__24UnmodifiableSet$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableSet$vtype	_jc_java_util_Collections__24UnmodifiableSet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24UnmodifiableSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24UnmodifiableSet$fields_struct _jc_java_util_Collections__24UnmodifiableSet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableSet$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_Collections__24UnmodifiableSet$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24UnmodifiableSet$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableSet$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSet$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableSet$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableCollection$vmethods	java_util_Collections__24UnmodifiableCollection;
	_jc_java_util_Collections__24UnmodifiableSet$vmethods	java_util_Collections__24UnmodifiableSet;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableSet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSet$refs {
    _jc_java_util_Collections__24UnmodifiableSet$sub_refs	java_util_Collections__24UnmodifiableSet;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_refs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_nonrefs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs	java_util_Collections__24UnmodifiableSet;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableSet$object {
	_jc_java_util_Collections__24UnmodifiableSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableSet$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableSet$vtype _jc_java_util_Collections__24UnmodifiableSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableSet$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableSet_H_ */
